# Infernet Client

Welcome to the Infernet Client, a lightweight Python library and CLI tool that streamlines interaction with the [Infernet Node](https://github.com/ritual-net/infernet-node) and the [Infernet Router](https://github.com/ritual-net/infernet-router). The Infernet Node provides robust computational capabilities through a well-defined API, while the Router allows for discovering nodes and containers running remotely, across the Infernet network.

This client aims to provide developers with a simple, efficient way to integrate and automate tasks using the Infernet [Node](#node) and [Router](#router).

## Features

- **Simple**: Streamlined methods for interacting with the Infernet Node and Router APIs.
- **Asynchronous**: Built-in async capabilities for improved performance.
- **Typed**: Complete type annotations for better editor support and reduced bugs.

## Documentation & Usage

See [infernet-client.docs.ritual.net](infernet-client.docs.ritual.net) or refer to `infernet_client/docs`.
